.. AUTO-GENERATED FILE -- DO NOT EDIT!

ISLP
====

:mod:`ISLP`
-----------
.. automodule:: ISLP

.. currentmodule:: ISLP

Functions
---------


.. autofunction:: ISLP.confusion_table


.. autofunction:: ISLP.load_data

